@@ -25,7 +25,7 @@ Otherwise on Linux, you will need the gtk or PyQt5/PyQt4 modules installed.
 gtk and PyQt4 modules are not available for Python 3,
 and this module does not work with PyGObject yet.
 
-Note: There seem sto be a way to get gtk on Python 3, according to:
+Note: There seems to be a way to get gtk on Python 3, according to:
     https://askubuntu.com/questions/697397/python3-is-not-supporting-gtk-module
 
 Cygwin is currently not supported.
@@ -43,7 +43,7 @@ A malicious user could rename or add programs with these names, tricking
 Pyperclip into running them with whatever permissions the Python process has.
 
 """
-__version__ = '1.6.0'
+__version__ = '1.6.4'
 
 import contextlib
 import ctypes
@@ -94,10 +94,16 @@ class PyperclipWindowsException(PyperclipException):
         super(PyperclipWindowsException, self).__init__(message)
 
 
+def _stringifyText(text):
+    if not isinstance(text, (str, int, float, bool)):
+        raise PyperclipException('only str, int, float, and bool values can be copied to the clipboard, not %s' % (text.__class__.__name__))
+    return str(text)
+
 
 def init_osx_pbcopy_clipboard():
 
     def copy_osx_pbcopy(text):
+        text = _stringifyText(text) # Converts non-str values to str.
         p = subprocess.Popen(['pbcopy', 'w'],
                              stdin=subprocess.PIPE, close_fds=True)
         p.communicate(input=text.encode(ENCODING))
@@ -114,6 +120,7 @@ def init_osx_pbcopy_clipboard():
 def init_osx_pyobjc_clipboard():
     def copy_osx_pyobjc(text):
         '''Copy string argument to clipboard'''
+        text = _stringifyText(text) # Converts non-str values to str.
         newStr = Foundation.NSString.stringWithString_(text).nsstring()
         newData = newStr.dataUsingEncoding_(Foundation.NSUTF8StringEncoding)
         board = AppKit.NSPasteboard.generalPasteboard()
@@ -135,6 +142,7 @@ def init_gtk_clipboard():
 
     def copy_gtk(text):
         global cb
+        text = _stringifyText(text) # Converts non-str values to str.
         cb = gtk.Clipboard()
         cb.set_text(text)
         cb.store()
@@ -168,6 +176,7 @@ def init_qt_clipboard():
         app = QApplication([])
 
     def copy_qt(text):
+        text = _stringifyText(text) # Converts non-str values to str.
         cb = app.clipboard()
         cb.setText(text)
 
@@ -183,6 +192,7 @@ def init_xclip_clipboard():
     PRIMARY_SELECTION='p'
 
     def copy_xclip(text, primary=False):
+        text = _stringifyText(text) # Converts non-str values to str.
         selection=DEFAULT_SELECTION
         if primary:
             selection=PRIMARY_SELECTION
@@ -210,6 +220,7 @@ def init_xsel_clipboard():
     PRIMARY_SELECTION='-p'
 
     def copy_xsel(text, primary=False):
+        text = _stringifyText(text) # Converts non-str values to str.
         selection_flag = DEFAULT_SELECTION
         if primary:
             selection_flag = PRIMARY_SELECTION
@@ -231,6 +242,7 @@ def init_xsel_clipboard():
 
 def init_klipper_clipboard():
     def copy_klipper(text):
+        text = _stringifyText(text) # Converts non-str values to str.
         p = subprocess.Popen(
             ['qdbus', 'org.kde.klipper', '/klipper', 'setClipboardContents',
              text.encode(ENCODING)],
@@ -259,6 +271,7 @@ def init_klipper_clipboard():
 
 def init_dev_clipboard_clipboard():
     def copy_dev_clipboard(text):
+        text = _stringifyText(text) # Converts non-str values to str.
         if text == '':
             warnings.warn('Pyperclip cannot copy a blank string to the clipboard on Cygwin. This is effectively a no-op.')
         if '\r' in text:
@@ -407,6 +420,9 @@ def init_windows_clipboard():
     def copy_windows(text):
         # This function is heavily based on
         # http://msdn.com/ms649016#_win32_Copying_Information_to_the_Clipboard
+
+        text = _stringifyText(text) # Converts non-str values to str.
+
         with window() as hwnd:
             # http://msdn.com/ms649048
             # If an application calls OpenClipboard with hwnd set to NULL,
@@ -445,6 +461,23 @@ def init_windows_clipboard():
     return copy_windows, paste_windows
 
 
+def init_wsl_clipboard():
+    def copy_wsl(text):
+        text = _stringifyText(text) # Converts non-str values to str.
+        p = subprocess.Popen(['clip.exe'],
+                             stdin=subprocess.PIPE, close_fds=True)
+        p.communicate(input=text.encode(ENCODING))
+
+    def paste_wsl():
+        p = subprocess.Popen(['powershell.exe', '-command', 'Get-Clipboard'],
+                             stdout=subprocess.PIPE,
+                             stderr=subprocess.PIPE,
+                             close_fds=True)
+        stdout, stderr = p.communicate()
+        # WSL appends "\r\n" to the contents.
+        return stdout[:-2].decode(ENCODING)
+
+    return copy_wsl, paste_wsl
 
 
 # Automatic detection of clipboard mechanisms and importing is done in deteremine_clipboard():
@@ -468,6 +501,11 @@ def determine_clipboard():
     elif os.name == 'nt' or platform.system() == 'Windows':
         return init_windows_clipboard()
 
+    if platform.system() == 'Linux':
+        with open('/proc/version', 'r') as f:
+            if "Microsoft" in f.read():
+                return init_wsl_clipboard()
+
     # Setup for the MAC OS X platform:
     if os.name == 'mac' or platform.system() == 'Darwin':
         try:
@@ -487,10 +525,10 @@ def determine_clipboard():
         else:
             return init_gtk_clipboard()
 
-        if _executable_exists("xclip"):
-            return init_xclip_clipboard()
         if _executable_exists("xsel"):
             return init_xsel_clipboard()
+        if _executable_exists("xclip"):
+            return init_xclip_clipboard()
         if _executable_exists("klipper") and _executable_exists("qdbus"):
             return init_klipper_clipboard()
 
